Description Usage Arguments Details Value See Also Examples
Peak correspondence is carried out by the 'lcms_groupChromPeaks' method,
with parameters obtained form IPO. Peak Correspondece consist in
grouping peaks on retention time axis with the purspose of associate
them to spectra on the mass/chage axis.
1 | IPO_group_peaks(peakdet_align, params)
|
peakdet_align |
A lcms_dataset with (1) detected ( |
params |
A converted parameters template from IPO parameters. |
Note: signal processing generally consists in three main steps:
(1) peak detection (find_peaks_cwp function),
(2) peak alignment (obiAdjust_Rtime function) and
(3) peak correspondence (IPO_group_peaks function).
The optimized set of parameters for this signal preprocessing can be obatained from IPO Package.
After this stage the peak table is finally obtained.
A lcms_dataset with (1) detected (find_peaks_cwp function),
(2) aligned (align_rtime function) and (3) grouped (IPO_group_peaks
function) peaks.
Other dataset functions:
find_peaks_cwp(),
lcms_dataset_load(),
lcms_dataset_save(),
lcms_fill_chrom_peaks(),
lcms_filter_mz(),
lcms_filter_polarity(),
lcms_filter_rt_min(),
lcms_filter_sample_type(),
lcms_meta_add(),
lcms_meta_export(),
lcms_plot_chrom_peak_image(),
lcms_plot_tics(),
lcms_rearrange_datafiles_by_class(),
lcms_retention_time_alignment_plot(),
lcms_tics(),
obiAdjust_Rtime(),
peakpicking_optimization(),
phData()
1 2 3 4 5 6 7 8 9 10 11 | ## Not run:
file_name <- system.file("extdata", "peakdet_align.rds", package = "AlpsLCMS")
peakdet_align <- base::readRDS(file_name)
opt_result_path <- system.file("extdata", package = "AlpsLCMS")
preproc_params <- lcms_read_ipo_to_xcms(opt_result_path)
peak_table <- IPO_group_peaks(peakdet_align, params = preproc_params)
print(peak_table)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.