Description Usage Arguments Value Author(s) See Also
View source: R/pre_processing.R
feature_values is a wrapper from xcms. The function creates an intensity
matrix with all the features.
1 2 3 4 5 6 7 8 9 |
... |
For |
For featureValues: a matrix with
feature values, columns representing samples, rows features. The order
of the features matches the order found in the
featureDefinitions(object) DataFrame. The rownames of the
matrix are the same than those of the featureDefinitions
DataFrame. NA is reported for features without
corresponding chromatographic peak in the respective sample(s).
For quantify: a SummarizedExperiment representing
the preprocessing results.
Johannes Rainer
XCMSnExp for information on the data object.
featureDefinitions to extract the DataFrame with the
feature definitions.
featureChromatograms to extract ion chromatograms for each
feature.
hasFeatures to evaluate whether the
XCMSnExp provides feature definitions.
groupval for the equivalent method on xcmsSet objects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.