Description Usage Value See Also Examples
View source: R/metabolite_identification.R
Takes a MAIT object and performs the metabolite search for the significant features
1 2 3 4 5 6 7 | lcms_identify_metabolites(
MAIT.object = NULL,
peakTolerance = 0.005,
database = NULL,
polarity = "positive",
printCSVfile = TRUE
)
|
An output table is stored in the folder (working directory)/tables/SearchTable.csv if printCSVfile is set to TRUE. More info at metaboliteTable.
Other metabolite identification functions:
lcms_peak_annotation(),
lcms_peak_table_boxplots(),
lcms_peak_table_pca(),
lcms_raw_data(),
lcms_sig_peaks_table(),
lcms_spectral_sig_features(),
lcms_to_mait(),
lcms_write_parameter_table()
Other dataset_peak_table functions:
lcms_dataset_load(),
lcms_peak_annotation(),
lcms_peak_table_boxplots(),
lcms_peak_table_pca(),
lcms_plot_tics(),
lcms_raw_data(),
lcms_sig_peaks_table(),
lcms_spectral_sig_features(),
lcms_tics(),
lcms_to_mait()
Other import/export functions:
lcms_convert_ipo_to_xcms(),
lcms_dataset_load(),
lcms_dataset_save(),
lcms_meta_export(),
lcms_meta_read(),
lcms_peak_annotation(),
lcms_raw_data(),
lcms_read_ipo_to_xcms(),
lcms_read_samples(),
lcms_rearrange_datafiles_by_class(),
lcms_sig_peaks_table(),
lcms_spectral_sig_features(),
lcms_to_mait(),
lcms_write_opt_params(),
lcms_write_parameter_table(),
phData()
1 2 3 4 5 6 7 | ## Not run:
file_name <- system.file("extdata", "peak_table_sig_ann.rds", package = "AlpsLCMS")
peak_table <- readRDS(file_name)
metabololite_table <- lcms_identify_metabolites(MAIT.object = peak_table,
peakTolerance = 0.005)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.