Description Usage Arguments Value See Also Examples
It plots the retention time correction vs the original retention time for each of the samples coloured by sample class.
1 |
data |
An alignend lcms_dataset. |
The plot for the retention time correction.
Other dataset functions:
IPO_group_peaks(),
find_peaks_cwp(),
lcms_dataset_load(),
lcms_dataset_save(),
lcms_fill_chrom_peaks(),
lcms_filter_mz(),
lcms_filter_polarity(),
lcms_filter_rt_min(),
lcms_filter_sample_type(),
lcms_meta_add(),
lcms_meta_export(),
lcms_plot_chrom_peak_image(),
lcms_plot_tics(),
lcms_rearrange_datafiles_by_class(),
lcms_tics(),
obiAdjust_Rtime(),
peakpicking_optimization(),
phData()
Other retention time correction functions:
obiAdjust_Rtime()
Other visualization functions:
lcms_peak_table_boxplots(),
lcms_peak_table_pca(),
lcms_plot_chrom_peak_image(),
lcms_plot_chrom(),
lcms_plot_tics(),
lcms_retcorgroup_optimization(),
peakpicking_optimization()
1 2 3 4 5 6 7 | ## Not run:
file_name <- system.file("extdata", "peakdet_align.rds", package = "AlpsLCMS")
data <- base::readRDS(file_name)
rta_plot <- lcms_retention_time_alignment_plot(data)
print(rta_plot)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.