Description Usage Arguments Value See Also Examples
View source: R/parameter_optimization.R
The function allows visulizing the parameter optimization results by IPO Package
allows in the RStudio console. Also you can save this results in plain text files
(i.e. a .CVS file).
1 2 3 4 5 6 7 | lcms_write_opt_params(
results_pp,
results_rtcg,
opt_result_path,
csv = TRUE,
console = TRUE
)
|
results_pp |
object from the |
results_rtcg |
object from the |
opt_result_path |
A directory to save the parameters file. |
csv |
if TRUE, it writes a file in csv format. |
console |
if TRUE, it displays the params on the console. |
A file with the params from the IPO optimization.
Other optimization functions:
default_peakpicking_params(),
lcms_convert_ipo_to_xcms(),
lcms_read_ipo_to_xcms(),
lcms_retcorgroup_optimization(),
peakpicking_optimization()
Other import/export functions:
lcms_convert_ipo_to_xcms(),
lcms_dataset_load(),
lcms_dataset_save(),
lcms_identify_metabolites(),
lcms_meta_export(),
lcms_meta_read(),
lcms_peak_annotation(),
lcms_raw_data(),
lcms_read_ipo_to_xcms(),
lcms_read_samples(),
lcms_rearrange_datafiles_by_class(),
lcms_sig_peaks_table(),
lcms_spectral_sig_features(),
lcms_to_mait(),
lcms_write_parameter_table(),
phData()
1 2 3 4 5 6 7 8 9 10 | ## Not run:
opt_result_path <-system.file("extdata", "ipo_opt", package = "AlpsLCMS")
file_name_pp <- system.file("extdata", "result_peakpicking.rds", package = "AlpsLCMS")
file_name_rcg <- system.file("extdata", "result_retcorgroup.rds", package = "AlpsLCMS")
result_peakpicking <- base::readRDS(file_name_pp)
result_retcorgroup <- base::readRDS(file_name_rcg)
lcms_write_opt_params(result_peakpicking, result_retcorgroup, opt_result_path)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.